Crate futures_poll_log

Crate futures_poll_log 

This module provides a way to wrap Futures in another Future that logs internal calls to poll. This allows a better understanding for when polls happen for both teaching and debugging.

Structs

LoggedFuture
The LoggedFuture struct wraps another Future and will log all poll calls.

Traits

LoggingExt
LoggingExt introduces the logging capabilities to any Future, as long as all its Item and Error can be printed.